@@ -806,7 +806,6 @@ class Structure(collections.Sequence, collections.Hashable):
         start_coords = np.array(self.frac_coords)
         end_coords = np.array(end_structure.frac_coords)
 
-        jimage=-np.array(np.around(end_coords-start_coords),int)
         vec = end_coords - start_coords #+ jimage
         intStructs = [Structure(self.lattice,[site.species_and_occu for site in self._sites],start_coords + float(x)/float(nimages) * vec) for x in xrange(0,nimages+1)]
         return intStructs;
@@ -1000,7 +999,7 @@ class Composition (collections.Mapping, collections.Hashable):
             #Ignore elements with zero amounts.
             if self[el] > self.amount_tolerance:
                 hashcode += el.Z 
-        return hashcode
+        return 7
     
     def __contains__(self,el):
         return el in self._elmap
@@ -1200,6 +1199,24 @@ class Composition (collections.Mapping, collections.Hashable):
             return Composition.from_formula(expanded_formula)
         return Composition.from_dict(get_sym_dict(formula, 1))
     
+    @property
+    def anonymized_formula(self):
+        reduced_comp = self.get_reduced_composition_and_factor()[0]
+        els = sorted(reduced_comp.elements, key = lambda e: reduced_comp[e])
+        ascii_code = 65
+        anon_formula = []
+        for e in els:
+            amt = reduced_comp[e]
+            if amt > 0:
+                if amt == 1:
+                    amt_str = ''
+                elif abs(amt % 1) < 1e-8:
+                    amt_str = str(int(amt))
+                else:
+                    amt_str = str(amt)
+                anon_formula.append('{}{}'.format(chr(ascii_code), amt_str))
+                ascii_code += 1
+        return "".join(anon_formula)
     
     def __repr__(self):
         return "Comp: " + self.formula
